==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkParallelCoordinatesView.java <==
// java wrapper for vtkParallelCoordinatesView object
//

package vtk;
import vtk.*;

public class vtkParallelCoordinatesView extends vtkRenderView
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetBrushMode_2(int id0);
  public void SetBrushMode(int id0)
    { SetBrushMode_2(id0); }

  private native void SetBrushModeToLasso_3();
  public void SetBrushModeToLasso()
    { SetBrushModeToLasso_3(); }

  private native void SetBrushModeToAngle_4();
  public void SetBrushModeToAngle()
    { SetBrushModeToAngle_4(); }

  private native void SetBrushModeToFunction_5();
  public void SetBrushModeToFunction()
    { SetBrushModeToFunction_5(); }

  private native void SetBrushModeToAxisThreshold_6();
  public void SetBrushModeToAxisThreshold()
    { SetBrushModeToAxisThreshold_6(); }

  private native int GetBrushMode_7();
  public int GetBrushMode()
    { return GetBrushMode_7(); }

  private native void SetBrushOperator_8(int id0);
  public void SetBrushOperator(int id0)
    { SetBrushOperator_8(id0); }

  private native void SetBrushOperatorToAdd_9();
  public void SetBrushOperatorToAdd()
    { SetBrushOperatorToAdd_9(); }

  private native void SetBrushOperatorToSubtract_10();
  public void SetBrushOperatorToSubtract()
    { SetBrushOperatorToSubtract_10(); }

  private native void SetBrushOperatorToIntersect_11();
  public void SetBrushOperatorToIntersect()
    { SetBrushOperatorToIntersect_11(); }

  private native void SetBrushOperatorToReplace_12();
  public void SetBrushOperatorToReplace()
    { SetBrushOperatorToReplace_12(); }

  private native int GetBrushOperator_13();
  public int GetBrushOperator()
    { return GetBrushOperator_13(); }

  private native void SetInspectMode_14(int id0);
  public void SetInspectMode(int id0)
    { SetInspectMode_14(id0); }

  private native void SetInspectModeToManipulateAxes_15();
  public void SetInspectModeToManipulateAxes()
    { SetInspectModeToManipulateAxes_15(); }

  private native void SetInpsectModeToSelectData_16();
  public void SetInpsectModeToSelectData()
    { SetInpsectModeToSelectData_16(); }

  private native int GetInspectMode_17();
  public int GetInspectMode()
    { return GetInspectMode_17(); }

  private native void SetMaximumNumberOfBrushPoints_18(int id0);
  public void SetMaximumNumberOfBrushPoints(int id0)
    { SetMaximumNumberOfBrushPoints_18(id0); }

  private native int GetMaximumNumberOfBrushPoints_19();
  public int GetMaximumNumberOfBrushPoints()
    { return GetMaximumNumberOfBrushPoints_19(); }

  private native void SetCurrentBrushClass_20(int id0);
  public void SetCurrentBrushClass(int id0)
    { SetCurrentBrushClass_20(id0); }

  private native int GetCurrentBrushClass_21();
  public int GetCurrentBrushClass()
    { return GetCurrentBrushClass_21(); }

  private native void ApplyViewTheme_22(vtkViewTheme id0);
  public void ApplyViewTheme(vtkViewTheme id0)
    { ApplyViewTheme_22(id0); }

  public vtkParallelCoordinatesView() { super(); }

  public vtkParallelCoordinatesView(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-20-aarch64.pkg.tar.xz: vtk/vtkParallelCoordinatesView.java <==
// java wrapper for vtkParallelCoordinatesView object
//

package vtk;
import vtk.*;

public class vtkParallelCoordinatesView extends vtkRenderView
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetBrushMode_2(int id0);
  public void SetBrushMode(int id0)
    { SetBrushMode_2(id0); }

  private native void SetBrushModeToLasso_3();
  public void SetBrushModeToLasso()
    { SetBrushModeToLasso_3(); }

  private native void SetBrushModeToAngle_4();
  public void SetBrushModeToAngle()
    { SetBrushModeToAngle_4(); }

  private native void SetBrushModeToFunction_5();
  public void SetBrushModeToFunction()
    { SetBrushModeToFunction_5(); }

  private native void SetBrushModeToAxisThreshold_6();
  public void SetBrushModeToAxisThreshold()
    { SetBrushModeToAxisThreshold_6(); }

  private native int GetBrushMode_7();
  public int GetBrushMode()
    { return GetBrushMode_7(); }

  private native void SetBrushOperator_8(int id0);
  public void SetBrushOperator(int id0)
    { SetBrushOperator_8(id0); }

  private native void SetBrushOperatorToAdd_9();
  public void SetBrushOperatorToAdd()
    { SetBrushOperatorToAdd_9(); }

  private native void SetBrushOperatorToSubtract_10();
  public void SetBrushOperatorToSubtract()
    { SetBrushOperatorToSubtract_10(); }

  private native void SetBrushOperatorToIntersect_11();
  public void SetBrushOperatorToIntersect()
    { SetBrushOperatorToIntersect_11(); }

  private native void SetBrushOperatorToReplace_12();
  public void SetBrushOperatorToReplace()
    { SetBrushOperatorToReplace_12(); }

  private native int GetBrushOperator_13();
  public int GetBrushOperator()
    { return GetBrushOperator_13(); }

  private native void SetInspectMode_14(int id0);
  public void SetInspectMode(int id0)
    { SetInspectMode_14(id0); }

  private native void SetInspectModeToManipulateAxes_15();
  public void SetInspectModeToManipulateAxes()
    { SetInspectModeToManipulateAxes_15(); }

  private native void SetInpsectModeToSelectData_16();
  public void SetInpsectModeToSelectData()
    { SetInpsectModeToSelectData_16(); }

  private native int GetInspectMode_17();
  public int GetInspectMode()
    { return GetInspectMode_17(); }

  private native void SetMaximumNumberOfBrushPoints_18(int id0);
  public void SetMaximumNumberOfBrushPoints(int id0)
    { SetMaximumNumberOfBrushPoints_18(id0); }

  private native int GetMaximumNumberOfBrushPoints_19();
  public int GetMaximumNumberOfBrushPoints()
    { return GetMaximumNumberOfBrushPoints_19(); }

  private native void SetCurrentBrushClass_20(int id0);
  public void SetCurrentBrushClass(int id0)
    { SetCurrentBrushClass_20(id0); }

  private native int GetCurrentBrushClass_21();
  public int GetCurrentBrushClass()
    { return GetCurrentBrushClass_21(); }

  private native void ApplyViewTheme_22(vtkViewTheme id0);
  public void ApplyViewTheme(vtkViewTheme id0)
    { ApplyViewTheme_22(id0); }

  public vtkParallelCoordinatesView() { super(); }

  public vtkParallelCoordinatesView(long id) { super(id); }
  public native long   VTKInit();

}
